@@ -4,7 +4,7 @@ from wsgi import App, Request, Response, redirect, abort
 from config import cfg
 from exceptions import BasicAuth, HttpError
 from routing import urls, add_apps, add_urls, url4, auto_routing
-from decorators import basic_auth, anticache, view
+from decorators import basic_auth, anticache, view, csrf_exempt
 from template import render_to_string, render
 from util import cached_property, cached_function
 from static import static_url
