@@ -179,9 +179,9 @@ else:
                 # забыли закрывающий слеш?
                 func, kwargs = urls.find(rq.path + '/')
                 if func:
-                    return wsgi.redirect(rq.path + '/')
+                    raise wsgi.redirect(rq.path + '/')
             wsgi.abort(404)
-        return func(rq, **kwargs)
+        return func, kwargs
 
     def add_urls(*rules):
         ''' Добавление правил списком'''
