@@ -246,7 +246,7 @@ class Response(Exception):
         """
         expires = kwargs.get('expires')
         if expires and isinstance(expires, timedelta):
-            kwargs['expires'] = expires.days * 86400 + expires.seconds 
+            kwargs['expires'] = expires.days * 86400 + expires.seconds
         key = key.encode(self.charset, self.encoding_errors)
         self.COOKIES[key] = val.encode(self.charset, self.encoding_errors)
         self.COOKIES[key]['path'] = path
@@ -295,16 +295,17 @@ class App(object):
         '''
         def routing_queue(routing):
             list_obj_from_str(routing)
-            if len(routing) == 1:
-                return routing[0]
             def wrapper(rq):
-                for func in routing:
+                for find_view in routing:
                     try:
-                        return func(rq)
+                        view_func, view_kwargs = find_view(rq)
                     except HttpError, e:
                         if e[0] == 404:
                             continue
                         raise
+                    for middleware in self.view_middlewares:
+                        middleware(rq, view_func, view_kwargs)
+                    return view_func(rq, **view_kwargs)
                 abort(404)
             return wrapper
 
@@ -328,6 +329,8 @@ class App(object):
             if hasattr(m, 'process_request')]
         self.response_middlewares = [m().process_response for m in mdls
             if hasattr(m, 'process_response')]
+        self.view_middlewares = [m().process_view for m in mdls
+            if hasattr(m, 'process_view')]
         self.response_middlewares.reverse()
         self.routing = routing_queue(cfg.ROUTING_QUEUE)
 
